<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Minnesota";
    var qsoPartyUrl = "http://www.w0aa.org/";
    var overlayUrl = "http://www.no5w.com/OverlayMinnesotaRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Aitkin", "ait");
  countySelection.options[1] = new Option("Anoka", "ano");
  countySelection.options[2] = new Option("Becker", "bec");
  countySelection.options[3] = new Option("Beltrami", "bel");
  countySelection.options[4] = new Option("Benton", "ben");
  countySelection.options[5] = new Option("BigStone", "big");
  countySelection.options[6] = new Option("BlueEarth", "blu");
  countySelection.options[7] = new Option("Brown", "bro");
  countySelection.options[8] = new Option("Carlton", "crl");
  countySelection.options[9] = new Option("Carver", "crv");
  countySelection.options[10] = new Option("Cass", "cas");
  countySelection.options[11] = new Option("Chippewa", "chp");
  countySelection.options[12] = new Option("Chisago", "chs");
  countySelection.options[13] = new Option("Clay", "cla");
  countySelection.options[14] = new Option("Clearwater", "cle");
  countySelection.options[15] = new Option("Cook", "coo");
  countySelection.options[16] = new Option("Cottonwood", "cot");
  countySelection.options[17] = new Option("CrowWing", "cro");
  countySelection.options[18] = new Option("Dakota", "dak");
  countySelection.options[19] = new Option("Dodge", "dod");
  countySelection.options[20] = new Option("Douglas", "dou");
  countySelection.options[21] = new Option("Faribault", "fai");
  countySelection.options[22] = new Option("Fillmore", "fil");
  countySelection.options[23] = new Option("Freeborn", "fre");
  countySelection.options[24] = new Option("Goodhue", "goo");
  countySelection.options[25] = new Option("Grant", "gra");
  countySelection.options[26] = new Option("Hennepin", "hen");
  countySelection.options[27] = new Option("Houston", "hou");
  countySelection.options[28] = new Option("Hubbard", "hub");
  countySelection.options[29] = new Option("Isanti", "isa");
  countySelection.options[30] = new Option("Itasca", "ita");
  countySelection.options[31] = new Option("Jackson", "jac");
  countySelection.options[32] = new Option("Kanabec", "knb");
  countySelection.options[33] = new Option("Kandiyohi", "knd");
  countySelection.options[34] = new Option("Kittson", "kit");
  countySelection.options[35] = new Option("Koochiching", "koo");
  countySelection.options[36] = new Option("LacQuiParle", "lac");
  countySelection.options[37] = new Option("Lake", "lak");
  countySelection.options[38] = new Option("LakeoftheWoods", "lkw");
  countySelection.options[39] = new Option("LeSueur", "les");
  countySelection.options[40] = new Option("Lincoln", "lin");
  countySelection.options[41] = new Option("Lyon", "lyo");
  countySelection.options[42] = new Option("Mahnomen", "mah");
  countySelection.options[43] = new Option("Marshall", "mrs");
  countySelection.options[44] = new Option("Martin", "mrt");
  countySelection.options[45] = new Option("McLeod", "mcl");
  countySelection.options[46] = new Option("Meeker", "mee");
  countySelection.options[47] = new Option("MilleLacs", "mil");
  countySelection.options[48] = new Option("Morrison", "mor");
  countySelection.options[49] = new Option("Mower", "mow");
  countySelection.options[50] = new Option("Murray", "mur");
  countySelection.options[51] = new Option("Nicollet", "nic");
  countySelection.options[52] = new Option("Nobles", "nob");
  countySelection.options[53] = new Option("Norman", "nor");
  countySelection.options[54] = new Option("Olmsted", "olm");
  countySelection.options[55] = new Option("OtterTail", "ott");
  countySelection.options[56] = new Option("Pennington", "pen");
  countySelection.options[57] = new Option("Pine", "pin");
  countySelection.options[58] = new Option("Pipestone", "pip");
  countySelection.options[59] = new Option("Polk", "pol");
  countySelection.options[60] = new Option("Pope", "pop");
  countySelection.options[61] = new Option("Ramsey", "ram");
  countySelection.options[62] = new Option("RedLake", "rdl");
  countySelection.options[63] = new Option("Redwood", "rdw");
  countySelection.options[64] = new Option("Renville", "ren");
  countySelection.options[65] = new Option("Rice", "ric");
  countySelection.options[66] = new Option("Rock", "roc");
  countySelection.options[67] = new Option("Roseau", "ros");
  countySelection.options[68] = new Option("Scott", "sco");
  countySelection.options[69] = new Option("Sherburne", "she");
  countySelection.options[70] = new Option("Sibley", "sib");
  countySelection.options[71] = new Option("Stearns", "str");
  countySelection.options[72] = new Option("Steele", "ste");
  countySelection.options[73] = new Option("Stevens", "stv");
  countySelection.options[74] = new Option("StLOUIS", "stl");
  countySelection.options[75] = new Option("Swift", "swi");
  countySelection.options[76] = new Option("Todd", "tod");
  countySelection.options[77] = new Option("Traverse", "tra");
  countySelection.options[78] = new Option("Wabasha", "wab");
  countySelection.options[79] = new Option("Wadena", "wad");
  countySelection.options[80] = new Option("Waseca", "wsc");
  countySelection.options[81] = new Option("Washington", "wsh");
  countySelection.options[82] = new Option("Watonwan", "wat");
  countySelection.options[83] = new Option("Wilkin", "wil");
  countySelection.options[84] = new Option("Winona", "win");
  countySelection.options[85] = new Option("Wright", "wri");
  countySelection.options[86] = new Option("YellowMedicine", "yel");
  addMarker(46.59220000, -93.43310000, "Aitkin", "ait");
  addMarker(45.22520000, -93.26540000, "Anoka", "ano");
  addMarker(46.93400000, -95.67840000, "Becker", "bec");
  addMarker(47.97490000, -95.00870000, "Beltrami", "bel");
  addMarker(45.69170000, -94.05630000, "Benton", "ben");
  addMarker(45.38140000, -96.46950000, "BigStone", "big");
  addMarker(44.05600000, -94.06980000, "BlueEarth", "blu");
  addMarker(44.30290000, -94.73880000, "Brown", "bro");
  addMarker(46.59320000, -92.67830000, "Carlton", "crl");
  addMarker(44.80660000, -93.76650000, "Carver", "crv");
  addMarker(46.87870000, -94.28050000, "Cass", "cas");
  addMarker(44.95190000, -95.64170000, "Chippewa", "chp");
  addMarker(45.51350000, -92.89430000, "Chisago", "chs");
  addMarker(46.89090000, -96.50340000, "Clay", "cla");
  addMarker(47.58580000, -95.37600000, "Clearwater", "cle");
  addMarker(47.85540000, -90.26090000, "Cook", "coo");
  addMarker(44.02180000, -95.16090000, "Cottonwood", "cot");
  addMarker(46.48080000, -94.08590000, "CrowWing", "cro");
  addMarker(44.69710000, -93.03100000, "Dakota", "dak");
  addMarker(44.02270000, -92.86190000, "Dodge", "dod");
  addMarker(45.93340000, -95.45440000, "Douglas", "dou");
  addMarker(43.67390000, -93.94800000, "Faribault", "fai");
  addMarker(43.67430000, -92.09000000, "Fillmore", "fil");
  addMarker(43.67390000, -93.34900000, "Freeborn", "fre");
  addMarker(44.45420000, -92.64150000, "Goodhue", "goo");
  addMarker(45.93410000, -96.01230000, "Grant", "gra");
  addMarker(45.01590000, -93.47200000, "Hennepin", "hen");
  addMarker(43.67380000, -91.47400000, "Houston", "hou");
  addMarker(47.10820000, -94.92110000, "Hubbard", "hub");
  addMarker(45.57310000, -93.26650000, "Isanti", "isa");
  addMarker(47.46210000, -93.73760000, "Itasca", "ita");
  addMarker(43.67420000, -95.15450000, "Jackson", "jac");
  addMarker(45.94500000, -93.28640000, "Kanabec", "knb");
  addMarker(45.15220000, -95.00620000, "Kandiyohi", "knd");
  addMarker(48.77190000, -96.81290000, "Kittson", "kit");
  addMarker(48.27890000, -93.75550000, "Koochiching", "koo");
  addMarker(45.05320000, -96.09560000, "LacQuiParle", "lac");
  addMarker(47.57240000, -91.41040000, "Lake", "lak");
  addMarker(48.87520000, -94.88570000, "LakeoftheWoods", "lkw");
  addMarker(44.36970000, -93.77470000, "LeSueur", "les");
  addMarker(44.41400000, -96.26570000, "Lincoln", "lin");
  addMarker(44.41300000, -95.84330000, "Lyon", "lyo");
  addMarker(47.32520000, -95.80930000, "Mahnomen", "mah");
  addMarker(48.35830000, -96.37800000, "Marshall", "mrs");
  addMarker(43.67420000, -94.55090000, "Martin", "mrt");
  addMarker(44.80480000, -94.25600000, "McLeod", "mcl");
  addMarker(45.10930000, -94.50960000, "Meeker", "mee");
  addMarker(45.90300000, -93.62030000, "MilleLacs", "mil");
  addMarker(46.06130000, -94.20870000, "Morrison", "mor");
  addMarker(43.67410000, -92.74930000, "Mower", "mow");
  addMarker(44.02220000, -95.76340000, "Murray", "mur");
  addMarker(44.30540000, -94.35730000, "Nicollet", "nic");
  addMarker(43.67450000, -95.75290000, "Nobles", "nob");
  addMarker(47.32500000, -96.46540000, "Norman", "nor");
  addMarker(44.01460000, -92.38430000, "Olmsted", "olm");
  addMarker(46.41240000, -95.71350000, "OtterTail", "ott");
  addMarker(48.05450000, -96.04160000, "Pennington", "pen");
  addMarker(46.07470000, -92.71800000, "Pine", "pin");
  addMarker(44.02300000, -96.25850000, "Pipestone", "pip");
  addMarker(47.83640000, -96.35010000, "Polk", "pol");
  addMarker(45.58590000, -95.44510000, "Pope", "pop");
  addMarker(45.00600000, -93.10590000, "Ramsey", "ram");
  addMarker(47.86220000, -96.09590000, "RedLake", "rdl");
  addMarker(44.44680000, -95.23030000, "Redwood", "rdw");
  addMarker(44.67430000, -94.99060000, "Renville", "ren");
  addMarker(44.36990000, -93.28230000, "Rice", "ric");
  addMarker(43.67490000, -96.25280000, "Rock", "roc");
  addMarker(48.76930000, -95.74760000, "Roseau", "ros");
  addMarker(44.67770000, -93.59470000, "Scott", "sco");
  addMarker(45.40290000, -93.83000000, "Sherburne", "she");
  addMarker(44.58700000, -94.19680000, "Sibley", "sib");
  addMarker(45.52890000, -94.59330000, "Stearns", "str");
  addMarker(44.02230000, -93.22600000, "Steele", "ste");
  addMarker(45.58600000, -96.00070000, "Stevens", "stv");
  addMarker(47.64040000, -92.44280000, "StLOUIS", "stl");
  addMarker(45.28210000, -95.68220000, "Swift", "swi");
  addMarker(46.07130000, -94.89960000, "Todd", "tod");
  addMarker(45.80360000, -96.55540000, "Traverse", "tra");
  addMarker(44.28110000, -92.20480000, "Wabasha", "wab");
  addMarker(46.58700000, -94.94590000, "Wadena", "wad");
  addMarker(44.02210000, -93.58720000, "Waseca", "wsc");
  addMarker(45.02100000, -92.88110000, "Washington", "wsh");
  addMarker(43.97830000, -94.61440000, "Watonwan", "wat");
  addMarker(46.32620000, -96.52630000, "Wilkin", "wil");
  addMarker(44.02000000, -91.68190000, "Winona", "win");
  addMarker(45.20080000, -93.88810000, "Wright", "wri");
  addMarker(44.73880000, -95.90600000, "YellowMedicine", "yel");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

